@@ -86,8 +86,6 @@ enum {
         NUMBER_OF_COLUMNS
 };
 
-static void     csm_inhibit_dialog_class_init  (CsmInhibitDialogClass *klass);
-static void     csm_inhibit_dialog_init        (CsmInhibitDialog      *inhibit_dialog);
 static void     csm_inhibit_dialog_finalize    (GObject               *object);
 
 G_DEFINE_TYPE (CsmInhibitDialog, csm_inhibit_dialog, GTK_TYPE_DIALOG)
@@ -1077,7 +1075,7 @@ csm_inhibit_dialog_init (CsmInhibitDialog *dialog)
 
         error = NULL;
         if (!gtk_builder_add_from_file (dialog->priv->xml,
-                                        GTKBUILDER_DIR "/" GTKBUILDER_FILE,
+                                        PKGDATADIR "/" GTKBUILDER_FILE,
                                         &error)) {
                 if (error) {
                         g_warning ("Could not load inhibitor UI file: %s",
